Command

Enum Command 

pub enum Command {
    GetVersion,
    ListDevices,
    GetWatchPolicy,
    SetWatchPolicy(Watch),
    Poll,
    GetDevice,
    SetDevice(Device),
}
Commands that can be sent to the gpsd server.

Variants



GetVersion

Gets the version of the gpsd server.

The server will respond with a Version object.



ListDevices

Lists all devices that gpsd knows about.

The server will respond with a Devices object.



GetWatchPolicy

Gets the current watch policy.

The server will respond with a Watch object.



SetWatchPolicy(Watch)

Sets the watch policy.

The server will respond with a Devices object followed by a Watch object.



Poll

Requests data from the last-seen fixes on all active GPS devices.

Devices must previously have their watch policy set to enabled to be pollable.

The server will respond with a Poll object.



GetDevice

Reports the state of a device.

The server will respond with a Device object.



SetDevice(Device)

Sets device-specific control bits.

The server will respond with a Device object.

Implementations



impl Command

pub fn set_watch_policy() -> SetWatchPolicyBuilder

Creates a new builder for the command.